@@ -27,7 +27,6 @@ To do test:
 
 '''
 
-
 # Module import
 import pygame
 import pygame.gfxdraw
@@ -36,11 +35,23 @@ import math
 import os
 import sys
 
+from halma_game.halma_model import HalmaModel
+from halma_game.halma_player import HalmaPlayer
+from halma_game.halma_player_01_A import HalmaPlayer01A
+from halma_game.halma_player_01_B import HalmaPlayer01B
+from halma_game.halma_player_02_A import HalmaPlayer02A
+from halma_game.halma_player_02_B import HalmaPlayer02B
+from halma_game.halma_player_03_A import HalmaPlayer03A
+from halma_game.halma_player_03_B import HalmaPlayer03B
+from halma_game.halma_player_04_A import HalmaPlayer04A
+from halma_game.halma_player_04_B import HalmaPlayer04B
+from halma_game.halma_player_human import HalmaPlayerHuman
+
 
 # Pygame initialization
 pygame.init()
 screen = pygame.display.set_mode((1280,720))    # Resolution set
-pygame.display.set_caption('Halma (Beta) v0.3.1')
+pygame.display.set_caption('Halma (Beta) v0.3.6')
 pygame.display.set_icon(pygame.image.load('assets/icon.png'))
 
 
