@@ -19,7 +19,7 @@ To do:
 
 import random
 import time
-from halma_player import HalmaPlayer
+from halma_game.halma_player import HalmaPlayer
 
 
 class HalmaStateNode:
